# Changelog

## Version 0.0.4 (development)
 - feat: Add node id output to exec command
 - fix: cleanup incorrect documentation

## Version 0.0.3 (development)
 - fix: handle empty files and check early
 - fix: handle broken return types of empty files
 - cleanup: remove RIOT from src
 - rework: make config classes

## Version 0.0.2 (development)

- feat: Add NM_CONFIG_DIR env var

## Version 0.0.1 (development)

- feat: Initial inet-nm-check
- feat: Initial inet-nm-commission
- feat: Initial inet-nm-exec
- feat: Initial inet-nm-free
- feat: Initial inet-nm-tmux
- feat: Initial inet-nm-tty-from-uid
- feat: Initial inet-nm-update-commissioned
- feat: Initial inet-nm-update-from-os
